.. currentmodule:: sardana.pool

:mod:`~sardana.pool`
====================

.. automodule:: sardana.pool

.. rubric:: Modules

.. toctree::
    :maxdepth: 1
    
    controller <pool/controller>
    pool <pool/pool>
    poolacquisition <pool/poolacquisition>
    poolaction <pool/poolaction>
    poolbasechannel <pool/poolbasechannel>
    poolbaseobject <pool/poolbaseobject>
    poolcontainer <pool/poolcontainer>
    poolcontroller <pool/poolcontroller>
    poolcontrollermanager <pool/poolcontrollermanager>
    poolcountertimer <pool/poolcountertimer>
    pooldefs <pool/pooldefs>
    poolelement <pool/poolelement>
    poolexception <pool/poolexception>
    poolexternal <pool/poolexternal>
    poolgroupelement <pool/poolgroupelement>
    poolinstrument <pool/poolinstrument>
    poolioregister <pool/poolioregister>
    poolmeasurementgroup <pool/poolmeasurementgroup>
    poolmetacontroller <pool/poolmetacontroller>
    poolmonitor <pool/poolmonitor>
    poolmotion <pool/poolmotion>
    poolmotor <pool/poolmotor>
    poolmotorgroup <pool/poolmotorgroup>
    poolmoveable <pool/poolmoveable>
    poolobject <pool/poolobject>
    poolonedexpchannel <pool/poolonedexpchannel>
    poolpseudocounter <pool/poolpseudocounter>
    poolpseudomotor <pool/poolpseudomotor>
    pooltwodexpchannel <pool/pooltwodexpchannel>
    poolutil <pool/poolutil>
    poolzerodexpchannel <pool/poolzerodexpchannel>
    
.. rubric:: Classes

.. hlist::
    :columns: 3

    * :data:`~sardana.pool.controller.Controller`
    * :data:`~sardana.pool.controller.MotorController`
    * :data:`~sardana.pool.controller.CounterTimerController`
    * :data:`~sardana.pool.controller.PseudoMotorController`
    
.. rubric:: Constants

.. hlist::
    :columns: 3

    * :data:`~sardana.pool.pooldefs.ControllerAPI`


